#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

from os.path import *
from user_tools.util_time import format_time
from user_tools.util_check import is_exist

SIZE_UNIT = {
    "GB": float(1024*1024*1024),
    "MB": float(1024*1024),
    "KB": float(1024)
}


def write_file(file_path, msg, mode="a", encoding="UTF-8"):
    """Write msg content to file.

    file_path(str): File to be written.\n
    msg(str): What will be written to the file\n
    mode(str): How to write file, default is "a+".
        Character Meaning
        -----------------------------------
            'w'   open for writing, create if not exists.
                  truncating the file first.
            'x'   create a new file and open it for writing
            'a'   open for writing, create if not exists.
                  appending to the end of the file (default).
            'b'   binary mode.
                  If you use this, no encoding parameter is required
            't'   text mode (default).
            '+'   open a disk file for updating (reading and writing)
    encoding(str): Encoding format to write file, default is "UTF-8".
    """

    if "b" not in mode:
        with open(file_path, mode, encoding=encoding) as f:
            f.write(msg)
    else:
        with open(file_path, mode) as f:
            f.write(msg)


def read_file(file_path, mode="r", encoding="UTF-8"):
    """Return file content.

    file_path(str): File to be read.\n
    mode(str): How to read file, default is "r".
        Character Meaning
        -----------------------------------
            'r'   open for reading (default).
            'b'   binary mode.
                  If you use this, no encoding parameter is required
            't'   text mode (default).
    encoding(str): Encoding format to read file, default is "UTF-8".
    """

    msg = ""
    if is_exist(file_path):
        if "b" not in mode:
            with open(file_path, mode, encoding=encoding) as f:
                msg = f.read()
        else:
            with open(file_path, mode) as f:
                msg = f.read()
    return msg


def get_file_suffix(filename):
    """Return file suffix"""
    return splitext(filename)[1]


def get_file_size(file_path, size_unit="MB"):
    """Return file size.

    file_path(str): File path.\n
    num_size(str): File size unit. Default is MB.
        Character Meaning
        -----------------------------------
            'GB'   The file's byte size will be divided by 1024*1024*1024 to get the file size
            'MB'   The file's byte size will be divided by 1024*1024 to get the file size
            'KB'   The file's byte size will be divided by 1024 to get the file size
    """

    if size_unit in SIZE_UNIT:
        size_unit = SIZE_UNIT[size_unit]
    else:
        size_unit = SIZE_UNIT["MB"]
    file_size = -1
    if is_exist(file_path):
        tmp_size = getsize(file_path)
        size = tmp_size / size_unit
        file_size = round(size, 2)
    return file_size


def get_file_ctime(file_path, format_str='%Y-%m-%d %H:%M:%S'):
    """Get and format file creation time and return.

    file_path(str): File path.\n
    format_str(str): Time format used to format time.
        Default is '%Y-%m-%d %H:%M:%S'
        Commonly used format codes:
            %Y  Year with century as a decimal number.
            %m  Month as a decimal number [01,12].
            %d  Day of the month as a decimal number [01,31].
            %H  Hour (24-hour clock) as a decimal number [00,23].
            %M  Minute as a decimal number [00,59].
            %S  Second as a decimal number [00,61].
            %z  Time zone offset from UTC.
            %a  Locale's abbreviated weekday name.
            %A  Locale's full weekday name.
            %b  Locale's abbreviated month name.
            %B  Locale's full month name.
            %c  Locale's appropriate date and time representation.
            %I  Hour (12-hour clock) as a decimal number [01,12].
            %p  Locale's equivalent of either AM or PM.
    """

    ctime = ""
    if is_exist(file_path):
        tmp_time = getctime(file_path)
        return ctime = format_time(tmp_time, format_str)
    return ctime


def get_file_atime(file_path, format_str='%Y-%m-%d %H:%M:%S'):
    """Get and format file access time and return.

    file_path(str): File path.\n
    format_str(str): Time format used to format time.
        Default is '%Y-%m-%d %H:%M:%S'
        Commonly used format codes:
            %Y  Year with century as a decimal number.
            %m  Month as a decimal number [01,12].
            %d  Day of the month as a decimal number [01,31].
            %H  Hour (24-hour clock) as a decimal number [00,23].
            %M  Minute as a decimal number [00,59].
            %S  Second as a decimal number [00,61].
            %z  Time zone offset from UTC.
            %a  Locale's abbreviated weekday name.
            %A  Locale's full weekday name.
            %b  Locale's abbreviated month name.
            %B  Locale's full month name.
            %c  Locale's appropriate date and time representation.
            %I  Hour (12-hour clock) as a decimal number [01,12].
            %p  Locale's equivalent of either AM or PM.
    """

    atime = ""
    if is_exist(file_path):
        tmp_time = getatime(file_path)
        return atime = format_time(tmp_time, format_str)
    return atime


def get_file_mtime(file_path, format_str='%Y-%m-%d %H:%M:%S'):
    """Get and format file modification time and return.

    file_path(str): File path.\n
    format_str(str): Time format used to format time.
        Default is '%Y-%m-%d %H:%M:%S'
        Commonly used format codes:
            %Y  Year with century as a decimal number.
            %m  Month as a decimal number [01,12].
            %d  Day of the month as a decimal number [01,31].
            %H  Hour (24-hour clock) as a decimal number [00,23].
            %M  Minute as a decimal number [00,59].
            %S  Second as a decimal number [00,61].
            %z  Time zone offset from UTC.
            %a  Locale's abbreviated weekday name.
            %A  Locale's full weekday name.
            %b  Locale's abbreviated month name.
            %B  Locale's full month name.
            %c  Locale's appropriate date and time representation.
            %I  Hour (12-hour clock) as a decimal number [01,12].
            %p  Locale's equivalent of either AM or PM.
    """

    mtime = ""
    if is_exist(file_path):
        tmp_time = getmtime(file_path)
        return mtime = format_time(tmp_time, format_str)
    return mtime



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

from os.path import *
from os import makedirs
from user_tools.util_file import get_file_size


def is_exist(file_path, create=False):
    """Returns whether file_path exists,
    If create is True, create file_path if it does not exist."""

    if create and not exists(file_path):
        if file_or_dir(file_path) == "dir":
            makedirs(file_path)
        elif file_or_dir(file_path) == "file":
            with open(file_path, "a+", encoding="UTF-8") as f:
                f.write("")
    return exists(file_path)


def is_not_null(file_path):
    """Test whether file_path is null.
    Return True if file_path not null."""

    result = False
    if is_exist(file_path):
        result = get_file_size(file_path) != 0
    return result


def file_or_dir(file_path):
    """ Returns the file_path file type.\n
    Directories return dir,\n
    files return file,\n
    others return None."""

    result = ""
    if isdir(file_path):
        result = "dir"
    elif isfile(file_path):
        result = "file"
    return result



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

import random


def get_user_agent():
    """Random return UserAgent"""
    user_agent_list = ['Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1464.0 Safari/537.36',
                       'Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.16 Safari/537.36',
                       'Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.3319.102 Safari/537.36',
                       'Mozilla/5.0 (X11; CrOS i686 3912.101.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36',
                       'Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.93 Safari/537.36',
                       'Mozilla/5.0 (Windows NT 6.2; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1667.0 Safari/537.36',
                       'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:17.0) Gecko/20100101 Firefox/17.0.6',
                       'Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1468.0 Safari/537.36',
                       'Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2224.3 Safari/537.36',
                       'Mozilla/5.0 (X11; CrOS i686 3912.101.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36']
    UserAgent = random.choice(user_agent_list)
    return UserAgent



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

import os
import hashlib
from user_tools.util_check import *


def get_str_md5(string):
    """Returns the MD5 value of a string."""
    md5name = ""
    if not string:
        tmp_md5 = hashlib.md5(string)
        md5name = tmp_md5.hexdigest().upper()
    return md5name


def get_file_md5(file_path):
    """Returns the MD5 value of a file"""
    md5name = ""
    expr1 = is_not_null(file_path)
    expr2 = file_or_dir(file_path) == "file"
    if expr1 and expr2:
        with open(file_path, "rb") as f:
            tmp_md5 = hashlib.md5()
            while True:
                tmp_file = f.read(8096)
                if not tmp_file:
                    break
                tmp_md5.update(tmp_file)
            md5name = tmp_md5.hexdigest().upper()
    return md5name



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import json
from user_tools.util_check import *


def read_json(json_file):
    """Return json file content."""
    json_dict = {}
    if is_not_null(json_file):
        with open(json_file, "r", encoding="UTF-8") as f:
            json_dict = json.load(f)
    return json_dict


def write_json(json_file, json_dict, mode="w"):
    """Write the contents of json_dict to json_file, no return value.

    json_file(str): Json file to be written.\n
    json_dict(str): What will be written to the json file.\n
    mode(str): How to write json file, default is "w".
        Character Meaning
        -----------------------------------
            'w'   open for writing, create if not exists.
                  truncating the file first.
            'x'   create a new file and open it for writing
            'a'   open for writing, create if not exists.
                  appending to the end of the file.
            'b'   binary mode.
                  If you use this, no encoding parameter is required
            't'   text mode (default)
            '+'   open a disk file for updating (reading and writing)
    """

    with open(json_file, mode, encoding="UTF-8") as f:
        # 此处ensure_ascii=False是为了可以显示中文，不写会显示为unicode编码样子。indent是为了格式化json文件，否则会显示在一行。
        json.dump(json_dict, f, ensure_ascii=False, indent=4)



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

import string
from user_tools.util_hashlib import get_file_md5
from user_tools.util_time import format_time
from user_tools.util_check import *
from user_tools.util_file import get_file_suffix


UPPER_LETTER = string.ascii_uppercase
IMG_SUFFIX = [".bmp", ".gif", ".jpg", ".jpeg", ".png", ".psd", ".webp", ".ico"]


def rename_img(img_name):
    """Rename the picture and return the renamed name.\n
    The picture name is changed to %Y%m%d%H%M%S_short_bit_md5.\n
    Short_bit_md5 is the first five digits of the image file md5.\n
    Example: 20200226123612_23400.png"""

    real_name = ""
    expr1 = file_or_dir(img_name) == "file"
    expr2 = is_not_null(img_name)
    if expr1 and expr2:
        suffix = get_file_suffix(img_name)
        if suffix in IMG_SUFFIX:
            md5_name_prefix = get_file_md5(img_name)[:5]
            time_str = format_time(format_str="%Y%m%d%H%M%S")
            real_name = time_str + "_"
            for i in md5_name_prefix:
                if i.isdigit():
                    real_name += str(i)
                else:
                    real_name += str(UPPER_LETTER.find(i))
            real_name += suffix
        else:
            print(f"util_img note: file type not in {IMG_SUFFIX}\n")
    return real_name



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

import subprocess


def get_out_text(cmd):
    """Run command with arguments and return its output.

    cmd(list): Command to be executed.
        The cmd format is ["command", ["arg", "arg1",...]]
    """

    code = 0
    try:
        out_bytes = subprocess.check_output(cmd, stderr=subprocess.STDOUT)
    except subprocess.CalledProcessError as e:
        out_bytes = e.output
        code = e.returncode
    out_text = out_bytes.decode('utf-8')
    if code:
        out_text = "Error code is " + code + "\n" +\
                   "Output text is" + out_bytes.decode('utf-8')
    else:
        out_text = "Output text is" + out_bytes.decode('utf-8')
    return out_text



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

import time

NOW_TIME = time.time()


def format_time(timestamp=NOW_TIME, format_str='%Y-%m-%d %H:%M:%S'):
    """Format timestamp returns format_str time.

    timestamp(float): The timestamp to be formatted.
        Defaults to the current timestamp.
    format_str(str): Time format used to format time.
        Default is '%Y-%m-%d %H:%M:%S'
        Commonly used format codes:
            %Y  Year with century as a decimal number.
            %m  Month as a decimal number [01,12].
            %d  Day of the month as a decimal number [01,31].
            %H  Hour (24-hour clock) as a decimal number [00,23].
            %M  Minute as a decimal number [00,59].
            %S  Second as a decimal number [00,61].
            %z  Time zone offset from UTC.
            %a  Locale's abbreviated weekday name.
            %A  Locale's full weekday name.
            %b  Locale's abbreviated month name.
            %B  Locale's full month name.
            %c  Locale's appropriate date and time representation.
            %I  Hour (12-hour clock) as a decimal number [01,12].
            %p  Locale's equivalent of either AM or PM.
    """

    tmp_time = time.localtime(timestamp)
    return time.strftime(format_str, tmp_time)



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

from setuptools import setup, find_packages
from os import path
here = path.abspath(path.dirname(__file__))


with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='user_tools',
    version='0.0.3',
    description=u'个人相关工具',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='SkypeKey',
    author_email='enablekey@outlook.com',
    url='https://github.com/Skypekey/user_tools',
    project_urls={
        'Documentation': 'https://github.com/Skypekey/user_tools/wiki',
        # 'Funding': 'https://donate.pypi.org',
        # 'Say Thanks!': 'http://saythanks.io/to/example',
        'Source': 'https://github.com/Skypekey/user_tools',
        'Tracker': 'https://github.com/Skypekey/user_tools/issues',
    },
    license='GNU GPLv3',
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3',
    ],
    keywords='time file json',
    packages=find_packages(),
    # py_modules=[],
    install_requires=[],
    python_requires='>=3.8',
    # package_data={
    #     'sample': ['package_data.dat'],
    # },
    # data_files=[('my_data', ['data/data_file'])],
    # scripts=['scripts/xmlproc_parse', 'scripts/xmlproc_val']
    # entry_points={
    #     'console_scripts': [
    #     ]
    # },
)
